import{s as tt,n as nt,o as at}from"../chunks/scheduler.9bc65507.js";import{S as it,i as rt,g as a,s,r as j,m as ot,A as lt,h as i,f as t,c as h,j as p,u as J,x as c,n as st,k as o,y as l,a as r,v as R,d as Z,t as W,w as Y}from"../chunks/index.707bf1b6.js";import{I as te}from"../chunks/IconCopyLink.d239c2d1.js";import{C as ht}from"../chunks/CodeBlock.a5ecddf7.js";function pt(Ae){let u,ne,f,g,Q,C,$e,B,Me="Efficient Training on CPU",ae,$,Ie="This guide focuses on training large models efficiently on CPU.",ie,d,_,D,y,ye,q,Xe="Mixed precision with IPEX",re,T,Ue="IPEX is optimized for CPUs with AVX-512 or above, and functionally works for CPUs with only AVX2. So, it is expected to bring performance benefit for Intel CPU generations with AVX-512 or above while CPUs with only AVX2 (e.g., AMD CPUs or older Intel CPUs) might result in a better performance under IPEX, but not guaranteed. IPEX provides performance optimizations for CPU training with both Float32 and BFloat16. The usage of BFloat16 is the main focus of the following sections.",oe,E,He="Low precision data type BFloat16 has been natively supported on the 3rd Generation Xeon® Scalable Processors (aka Cooper Lake) with AVX512 instruction set and will be supported on the next generation of Intel® Xeon® Scalable Processors with Intel® Advanced Matrix Extensions (Intel® AMX) instruction set with further boosted performance. The Auto Mixed Precision for CPU backend has been enabled since PyTorch-1.10. At the same time, the support of Auto Mixed Precision with BFloat16 for CPU and BFloat16 optimization of operators has been massively enabled in Intel® Extension for PyTorch, and partially upstreamed to PyTorch master branch. Users can get better performance and user experience with IPEX Auto Mixed Precision.",le,k,Se='Check more detailed information for <a href="https://intel.github.io/intel-extension-for-pytorch/cpu/latest/tutorials/features/amp.html" rel="nofollow">Auto Mixed Precision</a>.',se,m,w,O,A,Te,F,Le="IPEX installation:",he,M,ze="IPEX release is following PyTorch, to install via pip:",pe,I,Ne='<thead><tr><th align="center">PyTorch Version</th> <th align="center">IPEX version</th></tr></thead> <tbody><tr><td align="center">1.13</td> <td align="center">1.13.0+cpu</td></tr> <tr><td align="center">1.12</td> <td align="center">1.12.300+cpu</td></tr> <tr><td align="center">1.11</td> <td align="center">1.11.200+cpu</td></tr> <tr><td align="center">1.10</td> <td align="center">1.10.100+cpu</td></tr></tbody>',ce,X,ue,U,Be='Check more approaches for <a href="https://intel.github.io/intel-extension-for-pytorch/cpu/latest/tutorials/installation.html" rel="nofollow">IPEX installation</a>.',fe,v,P,K,H,Ee,G,qe="Usage in Trainer",de,S,Fe='Take an example of the use cases on <a href="https://github.com/huggingface/transformers/tree/main/examples/pytorch/question-answering" rel="nofollow">Transformers question-answering</a>',me,L,Ge=`<li>Training with IPEX using BF16 auto mixed precision on CPU:<pre> python run_qa.py \\
--model_name_or_path bert-base-uncased \\
--dataset_name squad \\
--do_train \\
--do_eval \\
--per_device_train_batch_size 12 \\
--learning_rate 3e-5 \\
--num_train_epochs 2 \\
--max_seq_length 384 \\
--doc_stride 128 \\
--output_dir /tmp/debug_squad/ \\
<b>--use_ipex \\</b>
<b>--bf16 --no_cuda</b></pre></li>`,ve,x,b,ee,z,ke,V,Ve="Practice example",xe,N,je='Blog: <a href="https://huggingface.co/blog/intel-sapphire-rapids" rel="nofollow">Accelerating PyTorch Transformers with Intel Sapphire Rapids</a>',ge;return C=new te({}),y=new te({}),A=new te({}),X=new ht({props:{code:"cGlwJTIwaW5zdGFsbCUyMGludGVsX2V4dGVuc2lvbl9mb3JfcHl0b3JjaCUzRCUzRCUzQ3ZlcnNpb25fbmFtZSUzRSUyMC1mJTIwaHR0cHMlM0ElMkYlMkZkZXZlbG9wZXIuaW50ZWwuY29tJTJGaXBleC13aGwtc3RhYmxlLWNwdQ==",highlighted:'pip install <span class="hljs-built_in">int</span>el_extension_for_pytorch==&lt;version_name&gt; -f https:<span class="hljs-comment">//developer.intel.com/ipex-whl-stable-cpu</span>'}}),H=new te({}),z=new te({}),{c(){u=a("meta"),ne=s(),f=a("h1"),g=a("a"),Q=a("span"),j(C.$$.fragment),$e=s(),B=a("span"),B.textContent=Me,ae=s(),$=a("p"),$.textContent=Ie,ie=s(),d=a("h2"),_=a("a"),D=a("span"),j(y.$$.fragment),ye=s(),q=a("span"),q.textContent=Xe,re=s(),T=a("p"),T.textContent=Ue,oe=s(),E=a("p"),E.textContent=He,le=s(),k=a("p"),k.innerHTML=Se,se=s(),m=a("h3"),w=a("a"),O=a("span"),j(A.$$.fragment),Te=s(),F=a("span"),F.textContent=Le,he=s(),M=a("p"),M.textContent=ze,pe=s(),I=a("table"),I.innerHTML=Ne,ce=s(),j(X.$$.fragment),ue=s(),U=a("p"),U.innerHTML=Be,fe=s(),v=a("h3"),P=a("a"),K=a("span"),j(H.$$.fragment),Ee=s(),G=a("span"),G.textContent=qe,de=ot("\n\nTo enable auto mixed precision with IPEX in Trainer, users should add `use_ipex`, `bf16` and `no_cuda` in training command arguments.\n"),S=a("p"),S.innerHTML=Fe,me=s(),L=a("ul"),L.innerHTML=Ge,ve=s(),x=a("h3"),b=a("a"),ee=a("span"),j(z.$$.fragment),ke=s(),V=a("span"),V.textContent=Ve,xe=s(),N=a("p"),N.innerHTML=je,this.h()},l(e){const n=lt("svelte-1phssyn",document.head);u=i(n,"META",{name:!0,content:!0}),n.forEach(t),ne=h(e),f=i(e,"H1",{class:!0});var _e=p(f);g=i(_e,"A",{id:!0,class:!0,href:!0});var Je=p(g);Q=i(Je,"SPAN",{});var Re=p(Q);J(C.$$.fragment,Re),Re.forEach(t),Je.forEach(t),$e=h(_e),B=i(_e,"SPAN",{"data-svelte-h":!0}),c(B)!=="svelte-9jbdy9"&&(B.textContent=Me),_e.forEach(t),ae=h(e),$=i(e,"P",{"data-svelte-h":!0}),c($)!=="svelte-16zn87f"&&($.textContent=Ie),ie=h(e),d=i(e,"H2",{class:!0});var we=p(d);_=i(we,"A",{id:!0,class:!0,href:!0});var Ze=p(_);D=i(Ze,"SPAN",{});var We=p(D);J(y.$$.fragment,We),We.forEach(t),Ze.forEach(t),ye=h(we),q=i(we,"SPAN",{"data-svelte-h":!0}),c(q)!=="svelte-1eqsya4"&&(q.textContent=Xe),we.forEach(t),re=h(e),T=i(e,"P",{"data-svelte-h":!0}),c(T)!=="svelte-8gr46r"&&(T.textContent=Ue),oe=h(e),E=i(e,"P",{"data-svelte-h":!0}),c(E)!=="svelte-8rqn29"&&(E.textContent=He),le=h(e),k=i(e,"P",{"data-svelte-h":!0}),c(k)!=="svelte-1orckb5"&&(k.innerHTML=Se),se=h(e),m=i(e,"H3",{class:!0});var Pe=p(m);w=i(Pe,"A",{id:!0,class:!0,href:!0});var Ye=p(w);O=i(Ye,"SPAN",{});var Qe=p(O);J(A.$$.fragment,Qe),Qe.forEach(t),Ye.forEach(t),Te=h(Pe),F=i(Pe,"SPAN",{"data-svelte-h":!0}),c(F)!=="svelte-utfx4z"&&(F.textContent=Le),Pe.forEach(t),he=h(e),M=i(e,"P",{"data-svelte-h":!0}),c(M)!=="svelte-yt7jgu"&&(M.textContent=ze),pe=h(e),I=i(e,"TABLE",{"data-svelte-h":!0}),c(I)!=="svelte-okkx16"&&(I.innerHTML=Ne),ce=h(e),J(X.$$.fragment,e),ue=h(e),U=i(e,"P",{"data-svelte-h":!0}),c(U)!=="svelte-6x6sx"&&(U.innerHTML=Be),fe=h(e),v=i(e,"H3",{class:!0});var be=p(v);P=i(be,"A",{id:!0,class:!0,href:!0});var De=p(P);K=i(De,"SPAN",{});var Oe=p(K);J(H.$$.fragment,Oe),Oe.forEach(t),De.forEach(t),Ee=h(be),G=i(be,"SPAN",{"data-svelte-h":!0}),c(G)!=="svelte-czcr4o"&&(G.textContent=qe),be.forEach(t),de=st(e,"\n\nTo enable auto mixed precision with IPEX in Trainer, users should add `use_ipex`, `bf16` and `no_cuda` in training command arguments.\n"),S=i(e,"P",{"data-svelte-h":!0}),c(S)!=="svelte-1t7mun5"&&(S.innerHTML=Fe),me=h(e),L=i(e,"UL",{"data-svelte-h":!0}),c(L)!=="svelte-1uocod9"&&(L.innerHTML=Ge),ve=h(e),x=i(e,"H3",{class:!0});var Ce=p(x);b=i(Ce,"A",{id:!0,class:!0,href:!0});var Ke=p(b);ee=i(Ke,"SPAN",{});var et=p(ee);J(z.$$.fragment,et),et.forEach(t),Ke.forEach(t),ke=h(Ce),V=i(Ce,"SPAN",{"data-svelte-h":!0}),c(V)!=="svelte-1au2cdg"&&(V.textContent=Ve),Ce.forEach(t),xe=h(e),N=i(e,"P",{"data-svelte-h":!0}),c(N)!=="svelte-w7zs5j"&&(N.innerHTML=je),this.h()},h(){o(u,"name","hf:doc:metadata"),o(u,"content",JSON.stringify(ct)),o(g,"id","efficient-training-on-cpu"),o(g,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),o(g,"href","#efficient-training-on-cpu"),o(f,"class","relative group"),o(_,"id","mixed-precision-with-ipex"),o(_,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),o(_,"href","#mixed-precision-with-ipex"),o(d,"class","relative group"),o(w,"id","ipex-installation"),o(w,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),o(w,"href","#ipex-installation"),o(m,"class","relative group"),o(P,"id","usage-in-trainer"),o(P,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),o(P,"href","#usage-in-trainer"),o(v,"class","relative group"),o(b,"id","practice-example"),o(b,"class","header-link block pr-1.5 text-lg no-hover:hidden with-hover:absolute with-hover:p-1.5 with-hover:opacity-0 with-hover:group-hover:opacity-100 with-hover:right-full"),o(b,"href","#practice-example"),o(x,"class","relative group")},m(e,n){l(document.head,u),r(e,ne,n),r(e,f,n),l(f,g),l(g,Q),R(C,Q,null),l(f,$e),l(f,B),r(e,ae,n),r(e,$,n),r(e,ie,n),r(e,d,n),l(d,_),l(_,D),R(y,D,null),l(d,ye),l(d,q),r(e,re,n),r(e,T,n),r(e,oe,n),r(e,E,n),r(e,le,n),r(e,k,n),r(e,se,n),r(e,m,n),l(m,w),l(w,O),R(A,O,null),l(m,Te),l(m,F),r(e,he,n),r(e,M,n),r(e,pe,n),r(e,I,n),r(e,ce,n),R(X,e,n),r(e,ue,n),r(e,U,n),r(e,fe,n),r(e,v,n),l(v,P),l(P,K),R(H,K,null),l(v,Ee),l(v,G),r(e,de,n),r(e,S,n),r(e,me,n),r(e,L,n),r(e,ve,n),r(e,x,n),l(x,b),l(b,ee),R(z,ee,null),l(x,ke),l(x,V),r(e,xe,n),r(e,N,n),ge=!0},p:nt,i(e){ge||(Z(C.$$.fragment,e),Z(y.$$.fragment,e),Z(A.$$.fragment,e),Z(X.$$.fragment,e),Z(H.$$.fragment,e),Z(z.$$.fragment,e),ge=!0)},o(e){W(C.$$.fragment,e),W(y.$$.fragment,e),W(A.$$.fragment,e),W(X.$$.fragment,e),W(H.$$.fragment,e),W(z.$$.fragment,e),ge=!1},d(e){e&&(t(ne),t(f),t(ae),t($),t(ie),t(d),t(re),t(T),t(oe),t(E),t(le),t(k),t(se),t(m),t(he),t(M),t(pe),t(I),t(ce),t(ue),t(U),t(fe),t(v),t(de),t(S),t(me),t(L),t(ve),t(x),t(xe),t(N)),t(u),Y(C),Y(y),Y(A),Y(X,e),Y(H),Y(z)}}}const ct={local:"efficient-training-on-cpu",sections:[{local:"mixed-precision-with-ipex",sections:[{local:"ipex-installation",title:"IPEX installation:"},{local:"usage-in-trainer",title:"Usage in Trainer"},{local:"practice-example",title:"Practice example"}],title:"Mixed precision with IPEX"}],title:"Efficient Training on CPU"};function ut(Ae){return at(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class xt extends it{constructor(u){super(),rt(this,u,ut,pt,tt,{})}}export{xt as component};
